@@ -27,7 +27,7 @@ _total_stack: Dict[Tuple[int, str], List[Tuple[int, str]]] = {}
 _info = {}
 _cur_id = 0
 _timer = time.time
-if sys.platform == 'win32':
+if sys.platform == "win32":
     _timer = time.clock
 
 
@@ -41,8 +41,7 @@ def stack_add(name, frame_name, frame_lineno, scope_name=None):
         _total_stack[_parent_stack[-1]].append(this_stack)
     _total_stack[this_stack] = []
     _parent_stack.append(this_stack)
-    _info[this_stack] = [len(_parent_stack) - 1, frame_name, frame_lineno,
-                         scope_name]
+    _info[this_stack] = [len(_parent_stack) - 1, frame_name, frame_lineno, scope_name]
 
     return this_stack
 
@@ -51,17 +50,16 @@ def stack_finish(this, cost):
     """Finish a given entry, and record its cost in time"""
     global _parent_stack
 
-    assert _parent_stack[-1] == this, \
-        'import stack does not end with this {}: {}'.format(this, _parent_stack)
+    assert (
+        _parent_stack[-1] == this
+    ), "import stack does not end with this {}: {}".format(this, _parent_stack)
     _parent_stack.pop()
     _info[this].append(cost)
 
 
 def log_stack_info(out_file, sorted=True, hide_fast=True):
     # Find all of the roots with import = 0
-    out_file.write(
-        '%5s %5s %-40s @ %s:%s\n'
-        % ('cum', 'local', 'name', 'file', 'line'))
+    out_file.write("%5s %5s %-40s @ %s:%s\n" % ("cum", "local", "name", "file", "line"))
     todo = [(value[-1], key) for key, value in _info.items() if value[0] == 0]
 
     if sorted:
@@ -87,9 +85,15 @@ def log_stack_info(out_file, sorted=True, hide_fast=True):
         # indent, cum_time, mod_time, name,
         # scope_name, frame_name, frame_lineno
         out_file.write(
-            '%5.1f %5.1f %-40s @ %s:%d\n' % (
-                info[-1] * 1000., mod_time * 1000.,
-                ('+' * info[0] + cur[1]), info[1], info[2]))
+            "%5.1f %5.1f %-40s @ %s:%d\n"
+            % (
+                info[-1] * 1000.0,
+                mod_time * 1000.0,
+                ("+" * info[0] + cur[1]),
+                info[1],
+                info[2],
+            )
+        )
 
         if sorted:
             c_times.sort()
@@ -100,6 +104,7 @@ def log_stack_info(out_file, sorted=True, hide_fast=True):
 
 _real_import = __import__
 
+
 def timed_import(name, globals=None, locals=None, fromlist=None, level=0):
     """Wrap around standard importer to log import time"""
     # normally there are 4, but if this is called as __import__ eg by
@@ -111,33 +116,33 @@ def timed_import(name, globals=None, locals=None, fromlist=None, level=0):
         # see where this is being called from, but it should be a rare case.
         scope_name = None
     else:
-        scope_name = globals.get('__name__', None)
+        scope_name = globals.get("__name__", None)
         if scope_name is None:
-            scope_name = globals.get('__file__', None)
+            scope_name = globals.get("__file__", None)
         if scope_name is None:
             scope_name = globals.keys()
         else:
             # Trim out paths before breezy
-            loc = scope_name.find('breezy')
+            loc = scope_name.find("breezy")
             if loc != -1:
                 scope_name = scope_name[loc:]
 
     # Figure out the frame that is doing the importing
     frame = sys._getframe(1)
-    frame_name = frame.f_globals.get('__name__', '<unknown>')
-    extra = ''
-    if frame_name.endswith('demandload'):
+    frame_name = frame.f_globals.get("__name__", "<unknown>")
+    extra = ""
+    if frame_name.endswith("demandload"):
         # If this was demandloaded, we have 3 frames to ignore
-        extra = '(demandload) '
+        extra = "(demandload) "
         frame = sys._getframe(4)
-        frame_name = frame.f_globals.get('__name__', '<unknown>')
-    elif frame_name.endswith('lazy_import'):
+        frame_name = frame.f_globals.get("__name__", "<unknown>")
+    elif frame_name.endswith("lazy_import"):
         # If this was lazily imported, we have 3 frames to ignore
-        extra = '[l] '
+        extra = "[l] "
         frame = sys._getframe(4)
-        frame_name = frame.f_globals.get('__name__', '<unknown>')
+        frame_name = frame.f_globals.get("__name__", "<unknown>")
     if fromlist:
-        extra += ' [{}]'.format(', '.join(map(str, fromlist)))
+        extra += " [{}]".format(", ".join(map(str, fromlist)))
     frame_lineno = frame.f_lineno
 
     this = stack_add(extra + name, frame_name, frame_lineno, scope_name)
@@ -154,7 +159,7 @@ def timed_import(name, globals=None, locals=None, fromlist=None, level=0):
 def _repr_regexp(pattern, max_len=30):
     """Present regexp pattern for logging, truncating if over max_len."""
     if len(pattern) > max_len:
-        return repr(pattern[:max_len - 3]) + "..."
+        return repr(pattern[: max_len - 3]) + "..."
     return repr(pattern)
 
 
@@ -166,14 +171,14 @@ def timed_compile(*args, **kwargs):
 
     # And who is requesting this?
     frame = sys._getframe(2)
-    frame_name = frame.f_globals.get('__name__', '<unknown>')
+    frame_name = frame.f_globals.get("__name__", "<unknown>")
 
-    extra = ''
-    if frame_name.endswith('lazy_regex'):
+    extra = ""
+    if frame_name.endswith("lazy_regex"):
         # If this was lazily compiled, we have 3 more frames to ignore
-        extra = '[l] '
+        extra = "[l] "
         frame = sys._getframe(5)
-        frame_name = frame.f_globals.get('__name__', '<unknown>')
+        frame_name = frame.f_globals.get("__name__", "<unknown>")
     frame_lineno = frame.f_lineno
     this = stack_add(extra + _repr_regexp(args[0]), frame_name, frame_lineno)
 
@@ -190,11 +195,11 @@ def timed_compile(*args, **kwargs):
 
 def install():
     """Install the hooks for measuring import and regex compile time."""
-    __builtins__['__import__'] = timed_import
+    __builtins__["__import__"] = timed_import
     re._compile = timed_compile  # type: ignore
 
 
 def uninstall():
     """Remove the import and regex compile timing hooks."""
-    __builtins__['__import__'] = _real_import
+    __builtins__["__import__"] = _real_import
     re._compile = _real_compile  # type: ignore
